#Changelog

##0.1.6
- Added tracked request path

##0.1.5
- Added template tags

###0.1.4
- Replaced urllib with requests for better ssl support

###0.1.3
 - Added geolocation with Telize

###0.1.2
 - Added support for better ip lookups with django-ipware

###0.1.1
 - Added Tests
 
##0.1.0
 - Initial commit